@@ -314,6 +314,7 @@ extern "C"{
   PPROC*  EDMAPROC edma_get_met_func (CLASSID ,EPChar);
   ESint32 EDMAPROC edma_set_met_func (CLASSID ,EPChar, PPROC*);
   ESint32 EDMAPROC edma_get_all_met_func (OBJID IdObj, PPROC **list);
+  ESint32 EDMAPROC edma_class_set_actual_version (EPChar, ESint32, ESint32);
   
  
   /* Shared Memory Primitives */
@@ -425,7 +426,9 @@ OBJID EDMAPROC edma_remove_superclass (OBJID id, EPChar apoint1, EUint32 flag);
 
   ESint32 EDMAPROC edma_idf_set_def (CLASSID,EUint32,EUint32,EUint32);
   ESint32 EDMAPROC edma_idf_set_prop (CLASSID,EUint32,EPChar,EPChar,EPChar,EUint32, EPChar);
-  ESint32 EDMAPROC edma_idf_set_met (CLASSID iC,EUint32 iP,EPChar ,EPChar,EByte,EByte,EByte);
+  ESint32 EDMAPROC edma_idf_set_met (CLASSID, EUint32, EPChar ,EPChar,EByte,EByte,EByte);
+  ESint32 EDMAPROC edma_idf_set_met2 (CLASSID class_id, EPChar met_name, EPChar met_sig, ESint32 iP,
+				      PPROC *f, ESint32 mvirtual, ESint32 mstatic, ESint32 mabstract);
   ESint32 EDMAPROC edma_idf_set_sclist (CLASSID ,EPChar	*);
   ESint32 EDMAPROC edma_idf_set_class_id (CLASSID );
   ESint32 EDMAPROC edma_idf_set_class_id1 (CLASSID );
