@@ -3,7 +3,7 @@
 #   EDMA: Entorno de Desarrollo Modular y Abierto
 #   Object Oriented and Componentware Framework  
 #
-#   Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+#   Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2021
 #             by David Martínez Oliveira
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-BASEDIR=/usr/local
+BASEDIR=/opt/edma_test
 EXT=so
 
 export EDMA_SYSTEM_PATH=${BASEDIR}
