@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -36,6 +36,7 @@
 
 #include <stdio.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include "portable.h"
 #include "const.h"
 #include "vglobal.h"
@@ -183,7 +184,16 @@ edma_add_local_class_property (CLASSID class_id, EPChar prop_name,
 /* edma_add_local_class_method
  *   Adds a new method to a local class (per-process defined class)
  */
-
+ESint32 EDMAPROC 
+edma_add_local_class_method (CLASSID class_id, EPChar met_name, EPChar met_sig, 
+			     PPROC *f, 
+			     ESint32 mvirtual, 
+			     ESint32 mstatic, 
+			     ESint32 mabstract)
+{
+  return edma_idf_set_met2 (class_id, met_name, met_sig, -1, f, mvirtual, mstatic, mabstract);
+}
+#if 0
 ESint32 EDMAPROC 
 edma_add_local_class_method (CLASSID class_id, EPChar met_name, EPChar met_sig, 
 			     PPROC *f, 
@@ -271,8 +281,6 @@ edma_add_local_class_method (CLASSID class_id, EPChar met_name, EPChar met_sig,
   pClass[class_id]->Met[indx].Abstract = mabstract;
   pClass[class_id]->Met[indx].Static = mstatic;
 
-  aux.Func = f;
-  pClass[class_id]->met_func[indx] = aux;
 
   /* Number of methods and virtual methods is calculated by 
    * edma_local_class_finish */
@@ -280,9 +288,187 @@ edma_add_local_class_method (CLASSID class_id, EPChar met_name, EPChar met_sig,
   /* Update nMet, nMetVir */
   gClass[class_id]->nMet++;
 
-  return indx;
-}
+  /* XXX: This code is duplicated from multidf... This needs to be unified*/
+  int i;
+  n= strlen (met_sig);
+  int nargs = 0;
+  for (i = 0; i < n; i++) {
+    if (met_sig[i] == 'S' || met_sig[i] == 'U' || met_sig[i] == 'C'
+	|| met_sig[i] == 'B' || met_sig[i] == 'W' || met_sig[i] == 'R'
+	|| met_sig[i] == 'Z' || met_sig[i] == 'A' || met_sig[i] == 'O'
+	|| met_sig[i] == 'X') nargs++;
+    if (met_sig[i] == 'r') i++; // Skip type FIXME: Won't work for type DW currently not used
+    if (met_sig[i] == 'L') {
+      char *aux = strchr (met_sig + i, ';');
+      if (aux != NULL) i = aux - met_sig + 1; // Skip class name
+      nargs++;
+    }
+			       
+  }
 
+  nargs++;
+  
+  // Create FFI context
+  int cnt = 0;
+  ffi_type **args = malloc (sizeof(ffi_type*)*(nargs+1));
+  ffi_type *rtype = &ffi_type_sint32;              // Default return type is int
+  memset (args, 0, sizeof(ffi_type*)*(nargs+1));
+  
+  args[cnt] = &ffi_type_uint32; // First parameter is always either OBJID or CLASSID
+  cnt++;
+  int is_ret = 0;
+  int is_out = 0;
+  
+  for (i = 0; i < n; i++)
+    {
+      is_ret = 0;
+      is_out = 0;
+      if (met_sig[i] == 'r') {is_ret = 1;; i++;}
+      if (met_sig[i] == 's') {is_out = 1; i ++;} 
+      switch (met_sig[i])
+	{
+	case 'S': // Signed ints
+	  {
+	    if (met_sig[i+1] == '8') args[cnt] = &ffi_type_sint8;
+      
+	    if (met_sig[i+1] == '1')
+	      {
+		if (met_sig[i + 2] == '6')
+		  {
+		    args[cnt] = &ffi_type_sint16;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i+2] == '2')
+		  {
+		    args[cnt] = &ffi_type_sint32;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+	  }
+	case 'U':
+	  {
+	    if (met_sig[i+1] == '8') args[cnt] = &ffi_type_uint8;
+      
+	    if (met_sig[i+1] == '1')
+	      {
+		if (met_sig[i + 2] == '6')
+		  {
+		    args[cnt] = &ffi_type_uint16;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i+2] == '2')
+		  {
+		    args[cnt] = &ffi_type_uint32;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+
+	  }
+	case 'R':
+	  {     
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i + 2] == '2')
+		  {
+		    args[cnt] = &ffi_type_float;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '6')
+	      {
+		if (met_sig[i+2] == '4')
+		  {
+		    args[cnt] = &ffi_type_double;
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+
+	  }
+
+	case 'L':
+	  {
+	    char *tmp;
+	    if ((tmp = strchr(met_sig[i+1], ';')) == NULL)
+	      edma_printf_err ("Missing colon on L. Invalid signature at %d .... : %s", i, met_sig);
+	    args[cnt] = &ffi_type_sint32; // Parameter is a class ID
+	    cnt++;
+	    i += (tmp - &met_sig[i] + 1);
+	  }
+	case 'A':
+	case 'O':
+	case 'X':
+	case 'Z':
+	  {
+	    //edma_printf ("adding Pointer (%c) (cnt:%d)\n", met_sig[i], cnt);
+	    args[cnt] = &ffi_type_pointer;
+	    cnt++;
+	    break;
+	  }
+	  
+	default:
+	  {
+	    edma_printf_err ("Unknown signature value!!!!");
+	    return -1;
+	    
+	  }
+	}
+      if (is_out) args[cnt - 1] = &ffi_type_pointer;
+      if (is_ret ) {
+	rtype = args[cnt - 1];
+	cnt--; // Discard current arg
+      }
+      
+  }
+
+  int ret = ffi_prep_cif (&aux.cfi, FFI_DEFAULT_ABI, nargs, rtype, args);
+  if (ret != FFI_OK) {
+    edma_printf_err ("FFI error : %d\n", ret);
+  }
+  aux.Func = f;
+  aux.nargs = nargs;
+  aux.rtype = rtype; // XXX: This may disappear in future
+  pClass[class_id]->met_func[indx] = aux;
+  
+  return indx;
+
+}
+#endif
 
 /* edma_add_local_class_superclass
  *   Adds a new superclass to a loca class (per-process defined class)
