@@ -55,15 +55,15 @@ extern "C"{
 
   /* Version Information*/
 #define VERSION_MA 0
-#define VERSION_MI 18
-#define VERSION_BUG 4
+#define VERSION_MI 19
+#define VERSION_BUG 1
 #define VERSION_STATUS "Dev"
-#define EVERSION "0.18.6"
+#define EVERSION "0.19.1"
 
 #define TMPDIR "/tmp/EDMAtmp"
 #define IDFDIR "/share/edma/idf/"
 
-#define GNUEDMADIR "/usr/local/"
+#define GNUEDMADIR "/opt/edma_test/"
 
 /** Maximum size for system tables ****************************/
 
