@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -51,7 +51,7 @@
  *   Returns -1 if the object idenfier 'id' is out of range or if it
  *   points to a free entry in the current object table
  */
-ESint32 EDMAINLINE
+ESint32 //EDMAINLINE
 edma_check_obj_id (OBJID id, EPChar msg) 
 {
 
@@ -71,7 +71,7 @@ edma_check_obj_id (OBJID id, EPChar msg)
 return 0;
 }
 
-ESint32 EDMAINLINE
+ESint32 //EDMAINLINE
 edma_check_obj_id1 (OBJID id, EPChar msg, EPChar str) 
 {
   if ((id < 0) || (id > nMaxObj)) 
@@ -88,7 +88,7 @@ return 0;
  *   Returns -1 if the class identifier 'cid' is out of range or it points
  *   to a currently undefined class
  */
-ESint32 EDMAINLINE
+ESint32 //EDMAINLINE
 edma_check_class_id (CLASSID cid, EPChar msg)
 {
 
@@ -114,7 +114,7 @@ edma_check_class_id (CLASSID cid, EPChar msg)
  *    Parses a class name to determine if a SIU proxy was specified 
  */
 /* FUnction returns offset between SIU Name and Class Name*/
-ESint32 EDMAINLINE
+ESint32 //EDMAINLINE
 _edma_parse_class_name (EPChar class_name, CLASSID *cid, CLASSID *siu_cid, 
 			ESint32 vmajor, ESint32 vminor)
 {
