@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -37,13 +37,19 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-
+  ESint32 edma_check_obj_id (OBJID id, EPChar msg);
+  ESint32 edma_check_obj_id1 (OBJID id, EPChar msg, EPChar str);
+  ESint32 edma_check_class_id (CLASSID cid, EPChar msg);
+  ESint32 _edma_parse_class_name (EPChar class_name, 
+				  CLASSID *cid, CLASSID *siu_cid,
+				  ESint32 vmajor, ESint32 vminor);
+  /*
   ESint32 EDMAINLINE edma_check_obj_id (OBJID id, EPChar msg);
   ESint32 EDMAINLINE edma_check_obj_id1 (OBJID id, EPChar msg, EPChar str);
   ESint32 EDMAINLINE edma_check_class_id (CLASSID cid, EPChar msg);
   ESint32 EDMAINLINE _edma_parse_class_name (EPChar class_name, 
 					     CLASSID *cid, CLASSID *siu_cid,
-					     ESint32 vmajor, ESint32 vminor);
+  					     ESint32 vmajor, ESint32 vminor); */
 #ifdef __cplusplus
 }
 #endif
