@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -64,7 +64,8 @@ extern "C"{
   ESint32 EDMAPROC edma_buffer_realloc (EDMAT_BUFFER*,EUint32);
 
   /* Dictionaries */
-  ESint32 EDMAINLINE edma_dict_map_string (EDMA_DICT, EPChar);
+  //ESint32 EDMAINLINE edma_dict_map_string (EDMA_DICT, EPChar);
+  ESint32 EDMAPROC edma_dict_map_string (EDMA_DICT, EPChar);
   EDMA_DICT EDMAPROC edma_dict_new (ESint32);
   ESint32 EDMAPROC edma_dict_free (EDMA_DICT);
   ESint32 EDMAPROC edma_dict_add_entry (EDMA_DICT, EPChar, ESint32);
