@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -63,7 +63,9 @@
  * January, 7th, 2004
  * Support for Include-like primitive
  */
- 
+
+#include <ffi.h>   /* UPDATE: 64bits fix*/
+
 #include <stdio.h>
 #include "portable.h"
 #include "const.h"
@@ -92,7 +94,8 @@
 ESint32 EDMAPROC 
 edma_ingridf_get_num_parsers (void) 
 {
-  return GVar->n_SubSystem[SS_INGRIDF];
+  return edma_subsystem_get_num_items (SS_INGRIDF);
+  //return GVar->n_SubSystem[SS_INGRIDF];
 }
 
 /* edma_ingridf_get_parser_class
@@ -696,10 +699,330 @@ edma_idf_set_prop (CLASSID iC, EUint32 iP,
   return size;
 }
 
+
+/* edma_idf_set_met2
+ *   Unification of edma_idf_set_met and edma_add_local_met
+*/
+
+
+ESint32 EDMAPROC 
+edma_idf_set_met2 (CLASSID class_id, EPChar met_name, EPChar met_sig, ESint32 iP,
+		   PPROC *f, 
+		   ESint32 mvirtual, 
+		   ESint32 mstatic, 
+		   ESint32 mabstract)
+{
+  ESint32    n, indx;
+  PROCMET    aux;
+
+  /* FIXME: Change parameter checking for macros as in GTK for example */
+  if (gClass[class_id] == 0)
+    {
+      edma_printf_err ("[_edma_idf_set_met] Invalid "
+		       "Class Identifier [%d]", class_id);
+      return -1;
+    }
+
+  if (met_name == NULL)
+    {
+      edma_printf_err ("%s", "[_edma_idf_set_met] Invalid "
+		       "method name");
+      return -1;
+    }
+
+  if (met_sig == NULL)
+    {
+      edma_printf_err ("%s", "[_edma_idf_set_met] Invalid "
+		       "method signature");
+      return -1;
+    }
+  /*
+  if (f == NULL)
+    {
+      edma_printf_err ("%s", "[_edma_idf_set_met] Invalid function");
+      return -1;
+    }
+  */
+  if (ProcMapTable[class_id] != CLASS_TEMP)
+    {
+      edma_printf_err ("[_edma_idf_set_met] Class %d "
+		       "not in definition state", class_id);
+      return -1;
+    }
+  
+  /* Check if the method already exists (name + signature)*/
+  /* FIXME: call '_edma_look4_met_single@locators.h' */
+  if ((edma_get_met_indx (class_id, met_name)) != -1)
+    {
+      edma_printf_err ("[_edma_idf_set_met] Method '%s:%s' "
+		       "already defined",
+		       met_name, met_sig);
+      return -1;
+    }
+
+  /* If method index is -1 it means we are calling this from edma_add_local_met
+   * In that case method table is being build dynamically and we have to allocate
+   * memory for the new method. Otherwise, the method table is already initialised
+   * when called from edma_idf_set_met
+   */
+  /* Alloc memory to store new method */
+  if (iP == -1)
+    {
+      n = indx = gClass[class_id]->nMet;
+      n ++;
+      
+      if ((pClass[class_id]->SysClass.hMet =
+	   edma_prealloc (pClass[class_id]->SysClass.hMet, sizeof(MET) * n)) == 0)
+	{
+	  edma_printf_err ("[edma_local_class_add_method] Can't alloc memory "
+			   "for method '%s:%s'",
+			   met_name, met_sig);
+	  return -1;
+	}
+      /* Alloc Memory to estore pointer to method code*/
+      if ((pClass[class_id]->SysClass.hMetFunc =
+	   edma_prealloc (pClass[class_id]->SysClass.hMetFunc, 
+			  sizeof(PROCMET) * n)) == 0)
+	{
+	  edma_printf_err ("[edma_local_class_add_method] Can't alloc memory "
+			   "for method '%s:%s'",
+			   met_name, met_sig);
+	  return -1;
+	}
+      
+      pClass[class_id]->Met = edma_pget (pClass[class_id]->SysClass.hMet);
+      pClass[class_id]->met_func = edma_pget (pClass[class_id]->SysClass.hMetFunc);
+    }
+  else
+    indx = iP;
+  
+  /* Store data */
+  strncpy (pClass[class_id]->Met[indx].IdMet, met_name, EDMA_MET_NAME_LEN);
+  strncpy (pClass[class_id]->Met[indx].Sign, met_sig, EDMA_MET_SIG_LEN);
+  pClass[class_id]->Met[indx].Virtual = mvirtual;
+  pClass[class_id]->Met[indx].Abstract = mabstract;
+  pClass[class_id]->Met[indx].Static = mstatic;
+  
+  
+  /* Number of methods and virtual methods is calculated by 
+   * edma_local_class_finish for local classes... otherwise it is already provided by
+   * the interface parser???? 
+   * XXX: Double check this*/
+  
+  /* Update nMet, nMetVir for local case */
+  if (iP == -1)  gClass[class_id]->nMet++;
+  
+  /* Build FFI information for method execution */
+  int i;
+  // First count number of parameters from the signature
+  n = strlen (met_sig);
+  int nargs = 0;
+  for (i = 0; i < n; i++) {
+    if (met_sig[i] == 'S' || met_sig[i] == 'U' || met_sig[i] == 'C'
+	|| met_sig[i] == 'B' || met_sig[i] == 'W' || met_sig[i] == 'R'
+	|| met_sig[i] == 'Z' || met_sig[i] == 'A' || met_sig[i] == 'O'
+	|| met_sig[i] == 'X') nargs++;
+    if (met_sig[i] == 'r') i++; // Skip type FIXME: Won't work for type DW currently not used
+    if (met_sig[i] == 'L') {
+      char *aux = strchr (met_sig + i, ';');
+      if (aux != NULL) i = aux - met_sig + 1; // Skip class name
+      nargs++;
+    }
+			       
+  }
+
+  nargs++;
+  
+  // Create FFI context
+  int cnt = 0, cnt1= 0;
+  ffi_type **args = malloc (sizeof(ffi_type*)*(nargs+1));
+  char     *targs = malloc (nargs + 1);
+  ffi_type *rtype = &ffi_type_sint32;              // Default return type is int
+  memset (args, 0, sizeof(ffi_type*)*(nargs+1));
+  memset (targs, 0, nargs+1);
+  args[cnt] = &ffi_type_uint32; // First parameter is always either OBJID or CLASSID
+  cnt++;
+  int is_ret = 0;
+  int is_out = 0;
+  
+  for (i = 0; i < n; i++)
+    {
+      is_ret = 0;
+      is_out = 0;
+      if (met_sig[i] == 'r') {is_ret = 1;; i++;}
+      if (met_sig[i] == 's') {is_out = 1; i ++;} 
+      switch (met_sig[i])
+	{
+	case 'S': // Signed ints
+	  {
+	    if (met_sig[i+1] == '8') {
+	      args[cnt] = &ffi_type_sint8;
+	      targs[cnt - 1] = 'I';
+	    }
+      
+	    if (met_sig[i+1] == '1')
+	      {
+		if (met_sig[i + 2] == '6')
+		  {
+		    args[cnt] = &ffi_type_sint16;
+		    targs[cnt-1] = 'I';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i+2] == '2')
+		  {
+		    args[cnt] = &ffi_type_sint32;
+		    targs[cnt-1] = 'I';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+	  }
+	case 'U':
+	  {
+	    if (met_sig[i+1] == '8') {
+	      args[cnt] = &ffi_type_uint8;
+	      targs[cnt-1] = 'I';
+	    }
+      
+	    if (met_sig[i+1] == '1')
+	      {
+		if (met_sig[i + 2] == '6')
+		  {
+		    args[cnt] = &ffi_type_uint16;
+		    targs[cnt-1] = 'I';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i+2] == '2')
+		  {
+		    args[cnt] = &ffi_type_uint32;
+		    targs[cnt-1] = 'I';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+
+	  }
+	case 'R':
+	  {     
+	    if (met_sig[i+1] == '3')
+	      {
+		if (met_sig[i + 2] == '2')
+		  {
+		    args[cnt] = &ffi_type_float;
+		    targs[cnt-1] = 'F';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+	      }
+	    
+	    if (met_sig[i+1] == '6')
+	      {
+		if (met_sig[i+2] == '4')
+		  {
+		    args[cnt] = &ffi_type_double;
+		    targs[cnt-1] = 'D';
+		    i++;
+		  }
+		else
+		  edma_printf_err ("Invalid signature at %d .... : %s", i, met_sig);
+		
+	      }
+	    cnt++;
+	    i++;
+
+	    break;
+
+	  }
+
+	case 'L':
+	  {
+	    char *tmp;
+	    if ((tmp = strchr(met_sig[i+1], ';')) == NULL)
+	      edma_printf_err ("Missing colon on L. Invalid signature at %d .... : %s", i, met_sig);
+	    args[cnt] = &ffi_type_sint32; // Parameter is a class ID
+	    targs[cnt-1] = 'I';
+	    cnt++;
+	    i += (tmp - &met_sig[i] + 1);
+	  }
+	case 'A':
+	case 'O':
+	case 'X':
+	case 'Z':
+	  {
+	    //edma_printf ("adding Pointer (%c) (cnt:%d)\n", met_sig[i], cnt);
+	    args[cnt] = &ffi_type_pointer;
+	    targs[cnt-1] = 'I';
+	    cnt++;
+	    break;
+	  }
+	  
+	default:
+	  {
+	    edma_printf_err ("Unknown signature value!!!!. Met: %s. Signature:%s", met_name, met_sig);
+	    return -1;
+	    
+	  }
+	}
+      if (is_out) {
+	args[cnt - 1] = &ffi_type_pointer;
+	targs[cnt-1] = 'I';
+      }
+      if (is_ret ) {
+	rtype = args[cnt - 1];
+	cnt--; // Discard current arg
+      }
+      
+  }
+  //edma_printf ("met_name: %s nargs:%d\n", met_name, nargs);
+  int ret = ffi_prep_cif (&aux.cfi, FFI_DEFAULT_ABI, nargs, rtype, args);
+  if (ret != FFI_OK) {
+    edma_printf_err ("FFI error : %d\n", ret);
+  }
+  aux.Func = f;
+  aux.nargs = nargs;
+  aux.targs = targs;
+  aux.rtype = rtype; // XXX: This may disappear in future
+  pClass[class_id]->met_func[indx] = aux;
+  //edma_printf ("Method: %s@%s -> %s\n", met_name, met_sig, targs);
+  return indx;
+
+}
+
 /* edma_idf_set_met
  *   Allows to define a class method for a class being defined
  */
-
+ESint32 EDMAPROC 
+edma_idf_set_met (CLASSID iC,EUint32 iP,EPChar mName,EPChar Sig,
+		  EByte vFlag, EByte aFlag, EByte sFlag) 
+{
+  return edma_idf_set_met2 (iC, mName, Sig, iP, NULL,vFlag, sFlag, aFlag);
+}
+#if 0
 ESint32 EDMAPROC 
 edma_idf_set_met (CLASSID iC,EUint32 iP,EPChar mName,EPChar Sig,
 		  EByte vFlag, EByte aFlag, EByte sFlag) 
@@ -742,12 +1065,35 @@ edma_idf_set_met (CLASSID iC,EUint32 iP,EPChar mName,EPChar Sig,
   pClass[iC]->Met[iP].Virtual = vFlag;
   pClass[iC]->Met[iP].Abstract = aFlag;
   pClass[iC]->Met[iP].Static = sFlag;
+
+  // Process Signature and create arguments array
+  // First calculate size
+  int i, n = strlen (Sig);
+  int nargs = 0;
+  for (i = 0; i < n; i++) {
+    if (Sig[i] == 'S' || Sig[i] == 'U' || Sig[i] == 'C'
+	|| Sig[i] == 'B' || Sig[i] == 'W' || Sig[i] == 'R'
+	|| Sig[i] == 'Z' || Sig[i] == 'A' || Sig[i] == 'O'
+	|| Sig[i] == 'X') nargs++;
+    if (Sig[i] == 'r') i++; // Skip type FIXME: Won't work for type DW currently not used
+    if (Sig[i] == 'L') {
+      char *aux = strchr (Sig + i, ';');
+      if (aux != NULL) i = aux - Sig + 1; // Skip class name
+      nargs++;
+    }
+			       
+  }
+  edma_printf ("Class %s. Method %s. Sig: %s Nargs : %d\n", gClass[iC]->ClassName, mName, Sig, nargs); 
+  
+  /* Create FFI objects */
+  //ffi_prep_cif (&pClass[iC]->Met[iP].cfi, FFI_DEFAULT_ABI, 
   
   if (vFlag)
     return 1;
   else
     return 0;
 }
+#endif
 
 /* edma_idf_set_sclist
  *   Allows to set a class list of superclass for a class being defined
@@ -828,7 +1174,8 @@ edma_idf_set_class_id (CLASSID class_id)
 {
   EUint32		i,size,size1;
 
-  printf ("%s. Prop: %p Met:%p\n", __FUNCTION__, pClass[class_id]->Prop , pClass[class_id]->Met);
+  edma_log ("%s. Prop: %p Met:%p\n", __FUNCTION__, 
+	    pClass[class_id]->Prop , pClass[class_id]->Met);
   if (class_id < MAX_CLASE)  /* If it is a Shared class */
     {
       if ((class_id < 0) || (class_id > GVar->nClases))
@@ -904,7 +1251,8 @@ edma_idf_set_class_id (CLASSID class_id)
   gClass[class_id]->CurrentVer = class_id;
   //_edma_class_update_versions (class_id);
 
-  if (pClass[class_id]->Prop == NULL)
+  //if (pClass[class_id]->Prop == NULL)
+  if (pClass[class_id]->Prop == NULL && pClass[class_id]->Met == NULL)
     {
       gClass[class_id]->Status = CLASS_DEF;
       ProcMapTable[class_id] = CLASS_DEF;
