@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -49,9 +49,11 @@ extern "C" {
   ESint32 EDMAPROC edma_idf_set_class_arch (CLASSID, ESint32, ESint32);
   ESint32 EDMAPROC edma_idf_set_class_impl (CLASSID, EPChar);
 
-  ESint32 EDMAPROC edma_idf_set_def (CLASSID,EUint32,EUint32,EUint32);
+  ESint32 EDMAPROC edma_idf_set_def  (CLASSID,EUint32,EUint32,EUint32);
   ESint32 EDMAPROC edma_idf_set_prop (CLASSID,EUint32,EPChar,EPChar,EPChar,EUint32, EPChar);
-  ESint32 EDMAPROC edma_idf_set_met (CLASSID iC,EUint32 iP,EPChar ,EPChar,EByte,EByte,EByte);
+  ESint32 EDMAPROC edma_idf_set_met  (CLASSID ,EUint32 ,EPChar ,EPChar,EByte,EByte,EByte);
+  ESint32 EDMAPROC edma_idf_set_met2 (CLASSID class_id, EPChar met_name, EPChar met_sig, ESint32 iP,
+				      PPROC *f, ESint32 mvirtual, ESint32 mstatic, ESint32 mabstract);
   ESint32 EDMAPROC edma_idf_set_sclist (CLASSID ,EPChar	*, EPChar *, EPChar *);
   ESint32 EDMAPROC _edma_idf_set_subsystems (CLASSID class_id);
   ESint32 EDMAPROC edma_idf_set_class_id (CLASSID );
