@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -72,6 +72,7 @@
 
 #include <pthread.h>
 #include <time.h>
+#include <ffi.h>
 
 #include "portable.h"
 #include "const.h"
@@ -164,7 +165,11 @@ extern "C"{
   } SYS_GLOBAL_VAR;
   
   typedef struct {
-    PPROC		*Func;
+    PPROC	  *Func;
+    EUint32       nargs;
+    EPChar        targs;
+    ffi_cif       cfi;    /* FFI context for function execution*/
+    ffi_type      *rtype; /* XXX: Double check if we really may need this value */
   } PROCMET;
   
   typedef struct {
