@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -21,6 +21,7 @@
  */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <edma.h>
 
 int main (int argc, char *argv[])
@@ -31,19 +32,26 @@ int main (int argc, char *argv[])
 
   /* Simple Object Creation */
   id = edma_new_obj ("HELLO_WORLD");
+  edma_met3 (id, "say"); 
   edma_obj_report (id);
   edma_free_obj (id);
 
 
   /* Single Static Inheritance*/
   id = edma_new_obj ("GRADUATE");
+  edma_wprop3 (id, "degree", "PhD");
+  edma_wprop3 (id, "name", "John Smith");
+  edma_met3 (id, "display");
+  edma_printf ("\n");
   edma_obj_report (id);
   edma_free_obj (id);
 
   /* SIU PROXY does exists*/
   id = edma_new_obj ("RUNABLE:HELLO_WORLD");
   edma_met3 (id, "say");
+  sleep (1);
   edma_obj_report (id);
+  
   edma_free_obj (id);
 
   /* SIU PROXY doesn't exists*/
