@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013, 2021
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -34,6 +34,7 @@ circle_set (OBJID id, EReal64 x, EReal64 y, EReal64 size)
 {
   CIRCLE_DAT  *m = edma_get_data_ref (id);
 
+  edma_printf_obj (id, "x: %f y:%f r:%f\n", x, y, size);
   m->x = x;
   m->y = y;
   m->radius = size;
@@ -102,9 +103,9 @@ define_classes ()
   edma_add_local_class_property (cid, "x", DT_EREAL64, E_L, 0);
   edma_add_local_class_property (cid, "y", DT_EREAL64, E_L, 0);
   edma_add_local_class_property (cid, "radius", DT_EREAL64, E_L, 0);
-  edma_add_local_class_method (cid, "set", "", 
+  edma_add_local_class_method (cid, "set", "R64R64R64", 
 			       (PPROC) circle_set, 0, 0, 0);
-  edma_add_local_class_method (cid, "resize", "", 
+  edma_add_local_class_method (cid, "resize", "R64", 
 			       (PPROC) circle_resize, 0, 0, 0);
   edma_add_local_class_method (cid, "draw", "", 
 			       (PPROC) circle_draw, 0, 0, 0);
